from tw.api import Widget, JSLink, CSSLink, js_callback
from tw import jquery

__all__ = ["Rating"]

rating_css = CSSLink(
    modname = __name__, 
    filename = 'static/ratings.css',)
rating_js = JSLink(
    modname = __name__, 
    filename = 'static/jquery.rating.js', 
    css=[rating_css],
    javascript=[jquery.packed])


class Rating(Widget):
    params = ["action", "average_text", "label_text", "submit_text", "on_click"]
    css_class = "rating"
    default = 0
    average_text = "Average Rating:"
    label_text = "Rate Me!"
    template = """\
<form class="${css_class}" title="${average_text} ${value}" 
      action="${action}" id="${id}">
    <label for="${id}_select" class="avg">${label_text}</label>
    <select id="${id}_select">
        <option value="0">0</option>
        <option value="1">1</option>
        <option value="2">2</option>
        <option value="3">3</option>
        <option value="4">4</option>
        <option value="5">5</option>
    </select>
    <input type="button" value="${submit_text}">
</form>"""

    javascript = [rating_js]
    include_dynamic_js_calls = True
    
    on_click = ''
    
    def update_params(self, d):
        super(Rating, self).update_params(d)
        self.add_call(jquery.function(js_callback(
            jquery.function('#'+d.id).rating()
            )))



from tw.api import Widget, JSLink, CSSLink, js_callback
from tw import jquery

__all__ = ["Rating"]

rating_css = CSSLink(
    modname = __name__, 
    filename = 'static/ratings.css')

rating_js = JSLink(
    modname = __name__, 
    filename = 'static/jquery.rating.js', 
    css=[rating_css],
    javascript=[jquery.jquery_js])


class Rating(Widget):
    params = ["action", "average_text", "label_text", "submit_text", "on_click"]
    css_class = "rating"
    default = 0

    average_text = "Average Rating:"
    average_text__doc = \
        "The text you'd like to appear as the average rating's label"

    label_text = "Rate Me!"
    label_text__doc = "The label for the select menu"

    submit_text = "Rate"
    submit_text__doc = "The text on the submit button"

    action = ""
    action__doc = "Where the rating should be POSTed"

    on_click = ""
    on_click__doc = "The js to be run when a json reponse is recieved"

    template = """\
<form class="${css_class}" title="${average_text} ${value}" 
      action="${action}" id="${id}">
    <label for="${id}_select" class="avg">${label_text}</label>
    <select id="${id}_select">
        <option value="0">0</option>
        <option value="1">1</option>
        <option value="2">2</option>
        <option value="3">3</option>
        <option value="4">4</option>
        <option value="5">5</option>
    </select>
    <input type="button" value="${submit_text}">
</form>
<script type="text/javascript">
    function ${id}_callback_handler(response)
    {
        ${on_click}
    }
    (function($){

    $('#${id}').rating();

    })(jQuery);
</script>
"""
    javascript = [rating_js]
    include_dynamic_js_calls = True

    def update_params(self, d):
        super(Rating, self).update_params(d)



# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__PROJECT__ = 'tw.rating'
__DESCRIPTION__ = 'Star Rater plugin'
__URL__ = 'http://toscawidgets.org/'
__VERSION__ = '0.8'
__AUTHOR__ = "Christopher Perkins, Alberto Valverde, Sean O'Donnell"
__EMAIL__ = 'chris@percious.com'
__COPYRIGHT__ = "Copyright 2008 Alberto Valverde, Sean O'Donnell, Christopher Perins"
__LICENSE__ = 'MIT'
